@@ -89,9 +89,14 @@ detector.dataserver_test = dataserver_test
 
 detector.load_PurdueShapes5_dataset(dataserver_train, dataserver_test)
 
-model = detector.LOADnet2(skip_connections=True, depth=32)
+model = detector.LOADnet2(skip_connections=True, depth=8)
+
+number_of_learnable_params = sum(p.numel() for p in model.parameters() if p.requires_grad)
+print("\n\nThe number of learnable parameters in the model: %d" % number_of_learnable_params)
+
+num_layers = len(list(model.parameters()))
+print("\n\nThe number of layers in the model: %d\n\n" % num_layers)
 
-dls.show_network_summary(model)
 
 detector.run_code_for_training_with_CrossEntropy_and_MSE_Losses(model)
 #detector.run_code_for_training_with_CrossEntropy_and_BCE_Losses(model)
