@@ -43,8 +43,8 @@ os.environ['PYTHONHASHSEED'] = str(seed)
 from DLStudio import *
 
 dls = DLStudio(
-                  dataroot = "/home/kak/ImageDatasets/PurdueShapes5/",
-#                  dataroot = "./data/",
+#                  dataroot = "/home/kak/ImageDatasets/PurdueShapes5/",
+                  dataroot = "./data/",
                   image_size = [32,32],
                   path_saved_model = "./saved_model",
                   momentum = 0.9,
@@ -79,17 +79,13 @@ detector.load_PurdueShapes5_dataset(dataserver_train, dataserver_test)
 model = detector.LOADnet2(skip_connections=True, depth=8)
 
 number_of_learnable_params = sum(p.numel() for p in model.parameters() if p.requires_grad)
-print("\n\nThe number of learnable parameters in the model: %d\n\n" % number_of_learnable_params)
+print("\n\nThe number of learnable parameters in the model: %d" % number_of_learnable_params)
 
 num_layers = len(list(model.parameters()))
 print("\n\nThe number of layers in the model: %d\n\n" % num_layers)
 
-#print(list(model.parameters()))
-
-dls.show_network_summary(model)
 
 detector.run_code_for_training_with_CrossEntropy_and_MSE_Losses(model)
-#detector.run_code_for_training_with_CrossEntropy_and_BCE_Losses(model)
 
 import pymsgbox
 response = pymsgbox.confirm("Finished training.  Start testing on unseen data?")
