@@ -28,7 +28,8 @@ os.environ['PYTHONHASHSEED'] = str(seed)
 from DLStudio import *
 
 dls = DLStudio(
-                  dataroot = "/home/kak/ImageDatasets/CIFAR-10/",
+#                  dataroot = "/home/kak/ImageDatasets/CIFAR-10/",
+                  dataroot = "./data/CIFAR-10/",
                   image_size = [32,32],
                   path_saved_model = "./saved_model",
                   momentum = 0.9,
@@ -45,7 +46,14 @@ dls = DLStudio(
 exp_seq = DLStudio.ExperimentsWithSequential( dl_studio = dls )
 exp_seq.load_cifar_10_dataset_with_augmentation()
 model = exp_seq.Net()
-dls.show_network_summary(model)
+
+number_of_learnable_params = sum(p.numel() for p in model.parameters() if p.requires_grad)
+print("\n\nThe number of learnable parameters in the model: %d\n\n" % number_of_learnable_params)
+
+num_layers = len(list(model.parameters()))
+print("\n\nThe number of layers in the model: %d\n\n" % num_layers)
+
+
 exp_seq.run_code_for_training(model)
 exp_seq.run_code_for_testing(model)
 
