@@ -46,8 +46,6 @@ dls = DLStudio(
                   batch_size = 4,
                   classes = ('plane','car','bird','cat','deer',
                              'dog','frog','horse','ship','truck'),
-                  debug_train = 0,
-                  debug_test = 0,
                   use_gpu = True,
               )
 
@@ -56,18 +54,19 @@ skip_con = DLStudio.SkipConnections( dl_studio = dls )
 #exp_skip.load_cifar_10_dataset_with_augmentation()
 skip_con.load_cifar_10_dataset()
 
-#model = skip_con.BMEnet(skip_connections=True, depth=32)         ## if you want to use skips
-model = skip_con.BMEnet(skip_connections=False, depth=32)         ## if you don't want to use skips
+model = skip_con.BMEnet(skip_connections=True, depth=32)         ## if you want to use skips
+#model = skip_con.BMEnet(skip_connections=False, depth=32)         ## if you don't want to use skips
+
 
 ## display network properties
-dls.show_network_summary(model)
 number_of_learnable_params = sum(p.numel() for p in model.parameters() if p.requires_grad)
 print("\n\nThe number of learnable parameters in the model: %d" % number_of_learnable_params)
 num_layers = len(list(model.parameters()))
 print("\nThe number of layers in the model: %d" % num_layers)
 
+
 ## training and testing
 skip_con.run_code_for_training(model, display_images=False)
 
-skip_con.run_code_for_testing(model)
+skip_con.run_code_for_testing(model, display_images=False)
 
