@@ -33,13 +33,14 @@ os.environ['PYTHONHASHSEED'] = str(seed)
 from DLStudio import *
 
 dls = DLStudio(
-                  dataroot = "/home/kak/ImageDatasets/PurdueShapes5MultiObject/",
-#                  dataroot = "./data/",
+#                  dataroot = "/home/kak/ImageDatasets/PurdueShapes5MultiObject/",
+                  dataroot = "./data/",
                   image_size = [64,64],
                   path_saved_model = "./saved_model",
                   momentum = 0.9,
                   learning_rate = 1e-4,
                   epochs = 6,
+#                  epochs = 1,
                   batch_size = 4,
                   classes = ('rectangle','triangle','disk','oval','star'),
                   debug_train = 1,
@@ -75,7 +76,6 @@ print("\n\nThe number of learnable parameters in the model: %d\n\n" % number_of_
 num_layers = len(list(model.parameters()))
 print("\n\nThe number of layers in the model: %d\n\n" % num_layers)
 
-dls.show_network_summary(model)
 
 segmenter.run_code_for_training_for_semantic_segmentation(model)
 
